==> jib-maven-plugin-0.1.0-sources.jar: com/google/cloud/tools/jib/registry/json/ErrorResponseTemplate.java <==
/*
 * Copyright 2017 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */

package com.google.cloud.tools.jib.registry.json;

import com.google.cloud.tools.jib.json.JsonTemplate;
import com.google.common.annotations.VisibleForTesting;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

/**
 * Template for the registry response body JSON when a request errored.
 *
 * <p>Example:
 *
 * <pre>{@code
 * {
 *   "errors": [
 *     {
 *       "code": "MANIFEST_UNKNOWN",
 *       "message": "manifest unknown",
 *       "detail": {"Tag": "latest"}
 *     }
 *   ]
 * }
 * }</pre>
 */
public class ErrorResponseTemplate extends JsonTemplate {

  private final List<ErrorEntryTemplate> errors = new ArrayList<>();

  public List<ErrorEntryTemplate> getErrors() {
    return Collections.unmodifiableList(errors);
  }

  @VisibleForTesting
  public ErrorResponseTemplate addError(ErrorEntryTemplate errorEntryTemplate) {
    errors.add(errorEntryTemplate);
    return this;
  }
}

==> jib-maven-plugin-0.1.5-sources.jar: com/google/cloud/tools/jib/registry/json/ErrorResponseTemplate.java <==
/*
 * Copyright 2017 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */

package com.google.cloud.tools.jib.registry.json;

import com.google.cloud.tools.jib.json.JsonTemplate;
import com.google.common.annotations.VisibleForTesting;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

/**
 * Template for the registry response body JSON when a request errored.
 *
 * <p>Example:
 *
 * <pre>{@code
 * {
 *   "errors": [
 *     {
 *       "code": "MANIFEST_UNKNOWN",
 *       "message": "manifest unknown",
 *       "detail": {"Tag": "latest"}
 *     }
 *   ]
 * }
 * }</pre>
 */
public class ErrorResponseTemplate implements JsonTemplate {

  private final List<ErrorEntryTemplate> errors = new ArrayList<>();

  public List<ErrorEntryTemplate> getErrors() {
    return Collections.unmodifiableList(errors);
  }

  @VisibleForTesting
  public ErrorResponseTemplate addError(ErrorEntryTemplate errorEntryTemplate) {
    errors.add(errorEntryTemplate);
    return this;
  }
}
